/*
*  Rubrica
*  file: file_old.c
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <gnome.h>
#include <libxml/tree.h>
#include <libxml/parser.h>

#include "rubrica.h"
#include "main.h"
#include "file.h" 
#include "file_old.h"
#include "error.h"
#include "view.h"

/* 
 *                                                                   
 *     routine di compatibilit. Leggono le rubriche create            
 *     con versioni precedenti alla 0.8                               
 *                                                                     
 *     Routine for backward compatibility. Reads old rubrica files     
 *                                                                    
 */
RubricaErrorType 
rubrica_file_old_parse_rubrica_doc(Rubrica *rubrica, xmlDocPtr doc, gint fileformat)
{
  xmlNodePtr nodo;
  gint n = 0;
  RubricaErrorType err = RE_NO_ERROR;
  
  nodo = doc->children;
  if (xmlIsBlankNode(nodo))
    nodo = nodo->next;


  if (nodo && nodo->name && g_strcasecmp(nodo->name, "Rubrica") == 0) 
    {
      nodo = nodo->children;      
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      
      if (fileformat == 1)
	{
	  g_print("\nload fileformat 1");

	  while (nodo)
	    {
	      err = rubrica_file_old_load_element_from_xml(rubrica, nodo); 
	      n++;
	      
	      nodo = nodo->next;
	      if(xmlIsBlankNode(nodo))
		nodo = nodo->next;
	    }
	}
      else /* fileformat == 2 */
	{
	  g_print("\nload fileformat 2");
	  rubrica_file_load_from_xmlnode(rubrica, nodo);  
	  n++;
	  
	  nodo = nodo->next;
 	  if(xmlIsBlankNode(nodo))
	    nodo = nodo->next;
	}
    }
  else
    err = RE_XML_DOC_NO_RUBRICA_HEADER;

  g_print("\nRubrica reads %d card%s", n, (n > 1 ? "s" : ""));

  return (RubricaErrorType) err;
}


RubricaErrorType
rubrica_file_old_load_element_from_xml(Rubrica *rubrica, xmlNodePtr xmlnode)
{
  RubricaItem *r;  
  GList *web = NULL, *email = NULL;
  GList *tel = NULL;
  xmlNodePtr figlio;
  gchar *buffer;

  /* i nodi xmlnode sono nodi xmlnew
     - devo estrarre i figli di xmlnew == xmldoc che sono:
       schedaxml, ...
  */
  /* se il nodo contiene caratteri di spaziatura */
  if (xmlIsBlankNode(xmlnode))
    xmlnode = xmlnode ->next;

  /* se il nodo non ha nome o il nome non  Indirizzo  */    
  if (xmlnode->name == NULL)                     
    return RE_XML_DOC_NO_RUBRICA_FIELD;
  
  if (g_strcasecmp(xmlnode->name, "Address") != 0)
    if (g_strcasecmp(xmlnode->name, "Indirizzo") != 0) 
      return RE_XML_DOC_NO_RUBRICA_FIELD;
  
  r = g_malloc(sizeof(RubricaItem));

  /* schedaxml */
  figlio = xmlnode->children;
  if(xmlIsBlankNode(figlio))
    figlio = figlio->next;
      
  if (figlio &&
      figlio->name && 
      ( (g_strcasecmp(figlio->name, "Card") == 0) ||
	(g_strcasecmp(figlio->name, "Scheda") == 0)))
    r->card = g_strdup((buffer = xmlNodeGetContent(figlio)) ? buffer : "");
  else     
    r->card = g_strdup("");
      
  if ((buffer = xmlGetProp(figlio, "deleting")) == NULL)
    buffer = xmlGetProp(figlio, "cancellabile");
  if (buffer)
    {
      r->delete = (g_strcasecmp(buffer, "TRUE") == 0) ? TRUE : FALSE;
      g_free(buffer);
    }
  else r->delete = TRUE;
  
  r->group.label = "";
  r->group.type  = 0;

  /* dati personali -- datixml -- */
  figlio = figlio->next; 
  if(xmlIsBlankNode(figlio))
    figlio = figlio->next;
  
  if (figlio &&
      figlio->name &&
      ( (g_strcasecmp(figlio->name, "Data") == 0) ||
        (g_strcasecmp(figlio->name, "Dati") == 0)))
    {
      /* carico i figli di datixml
	   - datixml=figlio 
	   - nodo = figlio di datixml
      */
      xmlNodePtr nodo;

      r->personal.middle = "";
      r->personal.prefix = "";
      r->personal.title = "";
      r->personal.birthknow = FALSE;
      r->personal.birthdate = time(NULL);	
      r->address.state = "";

      nodo = figlio->children;
      if(xmlIsBlankNode(nodo))
	nodo = nodo->next;
      r->personal.first = g_strdup((buffer = xmlNodeGetContent(nodo)) ? buffer : "");

      nodo = nodo->next;
      if(xmlIsBlankNode(nodo))
	nodo = nodo->next;
      r->personal.last = g_strdup((buffer = xmlNodeGetContent(nodo)) ? buffer : "");

      nodo = nodo->next;
      if(xmlIsBlankNode(nodo))
	nodo = nodo->next;
      r->personal.profession = g_strdup((buffer = xmlNodeGetContent(nodo)) ? buffer : "");
 
      nodo = nodo->next;
      if(xmlIsBlankNode(nodo))
	nodo = nodo->next;
      r->address.street = g_strdup((buffer = xmlNodeGetContent(nodo)) ? buffer : "");
      
      nodo = nodo->next;
      if(xmlIsBlankNode(nodo))
	nodo = nodo->next;
      r->address.number = g_strdup((buffer = xmlNodeGetContent(nodo)) ? buffer : "");

      nodo = nodo->next;
      if(xmlIsBlankNode(nodo))
	nodo = nodo->next;
      r->address.zip = g_strdup((buffer = xmlNodeGetContent(nodo)) ? buffer : "");

      nodo = nodo->next;
      if(xmlIsBlankNode(nodo))
	nodo = nodo->next;
      r->address.city = g_strdup((buffer = xmlNodeGetContent(nodo)) ? buffer : "");

      nodo = nodo->next;
      if(xmlIsBlankNode(nodo))
	nodo = nodo->next;
      r->address.province = g_strdup((buffer = xmlNodeGetContent(nodo)) ? buffer : "");

      nodo = nodo->next;
      if(xmlIsBlankNode(nodo))
	nodo = nodo->next;
      r->address.country = g_strdup((buffer = xmlNodeGetContent(nodo)) ? buffer : "");
    }
  else 
    {
      r->personal.first = r->personal.middle = r->personal.last = r->personal.profession 
	= r->personal.prefix = r->personal.title = "";
      r->personal.birthdate = time(NULL);    
    }

  /* web */
  figlio = figlio->next;
  if(xmlIsBlankNode(figlio))
    figlio = figlio->next;

  if (figlio &&
      figlio->name &&
      ( (g_strcasecmp(figlio->name, "WebAddresses") == 0) ||
	(g_strcasecmp(figlio->name, "Indirizzi_Web") == 0)))
    {
      gchar *buffer;
      xmlNodePtr nodo;
      
      nodo = figlio->children;
      if(xmlIsBlankNode(nodo))
	nodo = nodo->next;

      while(nodo)
	{
	  buffer = g_strdup(xmlNodeGetContent(nodo));
	  
	  web = g_list_append(web, buffer);
	  nodo = nodo->next;

	  if(nodo && xmlIsBlankNode(nodo))
	    nodo = nodo->next;	  
	}
      r->net.web = web;
    }
  else
    {
      r->net.web = NULL;
    }
  
  /* mail */
  figlio = figlio->next;
  if(xmlIsBlankNode(figlio))
    figlio = figlio->next;

  if (figlio &&
      figlio->name &&
      ( (g_strcasecmp(figlio->name, "EmailAddresses") == 0) ||
	(g_strcasecmp(figlio->name, "Indirizzi_Email") == 0)))
    {
      gchar *buffer;
      xmlNodePtr nodo;

      nodo = figlio->children;
      if(xmlIsBlankNode(nodo))
	nodo = nodo->next;

      while(nodo)
	{
	  buffer = g_strdup(xmlNodeGetContent(nodo));

	  email = g_list_append(email, buffer);

	  nodo = nodo->next;
	  if(nodo && xmlIsBlankNode(nodo))
	    nodo = nodo->next;	  
	}
      r->net.email = email;
    }  
  else
    {
      r->net.email = NULL;
    }
    
  /* telefono */
  figlio = figlio->next;
  if(xmlIsBlankNode(figlio))
    figlio = figlio->next;

  if (figlio &&
      figlio->name &&
      ( (g_strcasecmp(figlio->name, "TelephoneNumbers") == 0) ||
	(g_strcasecmp(figlio->name, "Numeri_Telefonici") == 0)))
    {
      xmlNodePtr nodo;
      TelNum *t;
      
      nodo = figlio->children;
      if(xmlIsBlankNode(nodo))
	nodo = nodo->next;	  
      while(nodo)
	{
	  gchar *type;

	  t = g_malloc(sizeof(TelNum));

	  type = xmlGetProp(nodo,"Type");
	  if (!type)
	    type=  xmlGetProp(nodo,"Tipo");
	  if (!type)
	    type= xmlGetProp(nodo,"type");
	  if (!type)
	    type= xmlGetProp(nodo,"tipo");

	  t->number = g_strdup(xmlNodeGetContent(nodo));
	  t->type = g_strdup(type);
	  
	  tel = g_list_append(tel, t);
	  nodo = nodo->next;
	  if(nodo && xmlIsBlankNode(nodo))
	    nodo = nodo->next;	  
	}
      r->phone.telephone = tel;
    }
  else
    {
      r->phone.telephone = NULL;
    }
  
  r->company.name = r->company.street = r->company.number 
    = r->company.zip = r->company.city  = r->company.province
    = r->company.country = r->company.web = r->company.email
    = r->company.operator = r->company.fax = r->company.green 
    = r->company.customer_care = r->company.notes = "";
  
  r->work.assigment =  r->work.organization = 
    r->work.department = r->work.subdep = 
    r->work.secretary = r->work.telephone = "";

  r->notes.is_married  = r->notes.has_children = 
    r->notes.birthknow = r->notes.anniverknow = FALSE;
  r->notes.birthdate = r->notes.anniverdate = time(NULL);
  r->notes.spouse =r->notes.children = r->notes.hobbies = 
    r->notes.notes = r->notes.pubkey = "";

  /* note */
  figlio = figlio->next;
  if(xmlIsBlankNode(figlio))
    figlio = figlio->next;

  if (figlio &&
      figlio->name &&
      ( (g_strcasecmp(figlio->name, "Notes") == 0) || 
	(g_strcasecmp(figlio->name, "Note") == 0)))
    {
      gchar *buffer;

      buffer = xmlNodeGetContent(figlio);

      if (buffer)
	r->notes.notes = g_strdup(buffer);
      else
	r->notes.notes = g_strdup("");      
    }
  else 
    r->notes.notes = g_strdup("");
  
  rubrica_append_item(rubrica, r);
//  rubrica_view_inc_indirizzi();

  return RE_NO_ERROR;
}
