/*
*  Rubrica
*  file: preview.c
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/


#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <string.h>
#include <gnome.h>
#include <libxml/parser.h>
#include <libxml/parserInternals.h>
#include <gconf/gconf-client.h>

#include "preview_int.h"
#include "preview.h"
#include "dictionary.h"
#include "rubrica.h"
#include "prefer.h"
#include "main.h" 
#include "error.h" 
#include "file_util.h"
#include "rubrica_type.h"

gchar *doc_version;

/* show the parsed xml file in a tree 
*/
gboolean rubrica_preview_show_file(char *filename, GtkWidget *ctree, 
				   RubricaErrorType *err) 
{ 
  xmlDocPtr doc;
  xmlNodePtr node;
  GtkWidget *label;
  gint count = 0;
  gchar *str;

  GtkCTreeNode *radice = NULL;
  gchar *buffer[2] = {"Rubrica", NULL};

  label = gtk_object_get_data(GTK_OBJECT(ctree), "addresses_read");

  if (!g_file_exists(filename))
    {
      *err = RE_FILE_NOT_EXIST;
            
      return FALSE;
    }
  else 
    g_print("\nRequested file %s exist...", filename);

  doc = xmlParseFile(filename);

  if (!doc)
    {
      *err = RE_PARSE_XML_DOC;
      
      xmlFreeDoc(doc);
      return FALSE;
    }
  else 
    g_print("\nFile %s loaded...", filename);
    

  /*    load dictionary
  */
  if (rubrica_preferences_get_use_default_dictionary())
    {
      if (rubrica_preferences_get_use_italian_dictionary())
	rubrica_dictionary_get_italian();
      else
	rubrica_dictionary_get_english();
    }
  else
    rubrica_dictionary_get_user_dictionary();

  radice = gtk_ctree_insert_node(GTK_CTREE(ctree), NULL, NULL, buffer, 10,
				 NULL, NULL, NULL, NULL, FALSE, FALSE);

  if (!doc->children || 
      !doc->children->name || 
      g_strcasecmp(doc->children->name, "Rubrica") != 0)
    {
      *err = RE_XML_DOC_NO_RUBRICA_HEADER;
      
      xmlFreeDoc(doc);
      return TRUE;
    }
  else 
    {
      gint fileformat = 0;
      
      g_print("\n%s is a rubrica's file", filename);

      fileformat = rubrica_file_get_fileformat(doc);

      node = doc->children->children;
      if(xmlIsBlankNode(node))
	node = node->next;

      if (fileformat < RUBRICA_FILE_FORMAT)
	{
	  while (node)
	    {
	      rubrica_preview_parse_old_node(node, ctree, radice);
	      
	      node = node->next;
	      if(node && xmlIsBlankNode(node))
		node = node->next; 

	      count++;
	    }
	}
      else
	{
	  while (node)
	    {
	      rubrica_preview_parse_node(node, ctree, radice);
	      
	      node = node->next;
	      if(node && xmlIsBlankNode(node))
		node = node->next; 

	      count++;
	    }
	}
    }

  str = g_strdup_printf("%d", count);
  gtk_label_set_text(GTK_LABEL(label), str);
  g_free(str);
  rubrica_preview_set_filename(filename);

  return FALSE; /* no errors */
}

void rubrica_preview_parse_node(xmlNodePtr xmlnode, GtkWidget *ctree, 
				GtkCTreeNode *radice)
{
  GConfClient *client;
  xmlNodePtr figlio = NULL;  
  GtkCTreeNode *genitore = NULL;
  GtkCTreeNode *treefiglio = NULL;

  client = gconf_client_get_default(); // rubrica_get_client();
  
  if (xmlnode && xmlnode->name &&                    /* se il nodo ha nome e */
      g_strcasecmp(xmlnode->name, "Card") == 0)      /* il nome  Scheda     */
    {
      gchar *buffer[2], *tmp = NULL, *tmp1 = NULL, *tmp2 = NULL;
      
      tmp = xmlGetProp(xmlnode, "name") ;
      buffer[0] = g_strdup(gconf_client_get_string(client, RUBRICA_KEY_DICT_CARD, 
						   NULL));
      buffer[1] = (tmp  ? g_strdup(tmp) : "");

      genitore = gtk_ctree_insert_node(GTK_CTREE(ctree), radice, NULL, buffer, 
				       10, NULL, NULL, NULL, NULL, FALSE, FALSE);

      tmp  = xmlGetProp(xmlnode, "created");      
//      tmp1 = rubrica_utils_convert_time(atoi(tmp), TRUE);
      tmp  = xmlGetProp(xmlnode, "last_change");      
//      tmp2 = rubrica_convert_time(atoi(tmp), TRUE);      
      
      /* l'ultimo figlio di card */
//      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_LAST_CHANGE, NULL);
      buffer[1] = tmp2;
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 
					 10, NULL, NULL, NULL, NULL, FALSE, FALSE);
/*
      buffer[0]  = gconf_client_get_string(client, RUBRICA_KEY_DICT_MODIFY, NULL);
      buffer[1]  = rubrica_convert_boolean(xmlGetProp(xmlnode, "modifying"));
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, treefiglio, buffer, 
					 10, NULL, NULL, NULL, NULL, FALSE, FALSE);
	   
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_DELETE, NULL);
      buffer[1] = rubrica_convert_boolean(xmlGetProp(xmlnode, "deleting"));
      gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, treefiglio, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, FALSE);
*/
//      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_CREATED, NULL);
      buffer[1] = tmp1; 
      gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, treefiglio, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, FALSE);      
    }

  figlio = xmlnode->children;
  if (xmlIsBlankNode(figlio))
    figlio = figlio->next;

  if (figlio && figlio->name &&
      g_strcasecmp(figlio->name, "Data") == 0)  
    {
      xmlNodePtr nodo;
      gchar *buffer[2], *tmp;
      gchar *buffer2[2];

      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_DATA, NULL);
      buffer[1] = "";
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 
					 10, NULL, NULL, NULL, NULL, FALSE, TRUE);
 
      nodo = figlio->children;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_FIRST_NAME, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : ""); 
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, FALSE);
      
      buffer2[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_BIRTHDAY, NULL);
//      buffer2[1] = rubrica_convert_time(atoi(xmlGetProp(nodo, "birthday")), FALSE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_MIDDLE_NAME, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, FALSE);
      
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_LAST_NAME, NULL);
      buffer[1] = ((tmp  = xmlNodeGetContent(nodo)) ?  tmp : "");  
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, FALSE);
      
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_PROFESSION, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, FALSE);
      
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_NAME_PREFIX, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ?  tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, FALSE);
      
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_TITLE, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, FALSE);         

      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer2, 
			    10, NULL, NULL, NULL, NULL, FALSE, FALSE);
    }

  figlio = figlio->next;
  if (xmlIsBlankNode(figlio))
    figlio = figlio->next;
  if (figlio && figlio->name &&
      g_strcasecmp(figlio->name, "Address") == 0)  
    {
      xmlNodePtr nodo;
      gchar *buffer[2], *tmp;

      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_ADDRESS, NULL);
      buffer[1] = "";
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 
					 10, NULL, NULL, NULL, NULL, FALSE, TRUE);
    
      nodo = figlio->children;    
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_STREET, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : ""); 
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, TRUE);    
  
      nodo   = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_STREET_NUMBER, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, TRUE);
      
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_ZIP_CODE, NULL);
      buffer[1] = ((tmp  = xmlNodeGetContent(nodo)) ?  tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_CITY, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_PROVINCE, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ?  tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, TRUE);
      
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_STATE, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;     
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_COUNTRY, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, TRUE);
    }

  figlio = figlio->next;
  if (xmlIsBlankNode(figlio))
    figlio = figlio->next;
  if (figlio && figlio->name &&
      g_strcasecmp(figlio->name, "WebAddresses") == 0)  
    {
      xmlNodePtr nodo;
      gchar *buffer[2];

      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_WEB_ADDRESS, NULL);
      buffer[1] = "";
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 
					 10, NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = figlio->children;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      while (nodo)
	{
	  gchar *tmp;

	  tmp = xmlNodeGetContent(nodo);
	  if (tmp)
	    {
	      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_WEB, NULL);
	      buffer[1] = tmp;
	      
	      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
				    NULL, NULL, NULL, NULL, FALSE, TRUE);

	      nodo = nodo->next;
	      if (nodo && xmlIsBlankNode(nodo))
		nodo = nodo->next;
	    }
	}    
    }      

  figlio = figlio->next;
  if (xmlIsBlankNode(figlio))
    figlio = figlio->next;
  if (figlio && figlio->name &&
      g_strcasecmp(figlio->name, "EmailAddresses") == 0)  
    {
      xmlNodePtr nodo;
      gchar *buffer[2];

      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_EMAIL_ADDRESS, NULL);
      buffer[1] = "";
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 
					 10, NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = figlio->children;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      while (nodo)
	{
	  gchar *tmp;

	  tmp = xmlNodeGetContent(nodo);
	  if (tmp)
	    {
	      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_EMAIL, NULL);
	      buffer[1] = tmp;
      
	      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10,
				    NULL, NULL, NULL, NULL, FALSE, TRUE);	      
	      
	      nodo = nodo->next;
	      if (nodo && xmlIsBlankNode(nodo))
		nodo = nodo->next;
	    }
	}    
    }

  figlio = figlio->next;
  if (xmlIsBlankNode(figlio))
    figlio = figlio->next;
  if (figlio && figlio->name &&
      g_strcasecmp(figlio->name, "TelephoneNumbers") == 0)  
    {
      xmlNodePtr nodo;
      gchar *buffer[2];

      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_TELEPHONE_LIST, NULL);
      buffer[1] = "";
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 
					 10, NULL, NULL, NULL, NULL, FALSE, TRUE);      
      nodo = figlio->children;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      while (nodo)
	{
	  gchar *tmp1 = NULL, *tmp2 = NULL;

	  tmp1 = xmlNodeGetContent(nodo);
	  if ((strcmp(nodo->properties->name, "type") == 0))
	    tmp2 = xmlGetProp(nodo, "type");
	  
	  if (tmp1)
	    {
	      buffer[0] = gconf_client_get_string(client, 
						  RUBRICA_KEY_DICT_TELEPHONE_NUMBER, 
						  NULL);
	      buffer[1] = tmp1;
	      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
				    NULL, NULL, NULL, NULL, FALSE, TRUE);

	      buffer[0] =  gconf_client_get_string(client, 
						   RUBRICA_KEY_DICT_TELEPHONE_TYPE, 
						   NULL);
	      buffer[1] = tmp2;
	      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
				    NULL, NULL, NULL, NULL, FALSE, TRUE);	      
	      
	      nodo = nodo->next;
	      if (nodo && xmlIsBlankNode(nodo))
		nodo = nodo->next;
	    }
	}    
    }
     
  figlio = figlio->next;
  if (xmlIsBlankNode(figlio))
    figlio = figlio->next;
  if (figlio && figlio->name &&
      g_strcasecmp(figlio->name, "Company") == 0)  
    {
      xmlNodePtr nodo = NULL;
      gchar *buffer[2], *tmp;

      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_COMPANY, NULL);
      buffer[1] = "";
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 
					 10, NULL, NULL, NULL, NULL, FALSE, TRUE);
	          
      nodo = figlio->children;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_COMPANY_NAME, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");;
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_STREET, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_STREET_NUMBER, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_ZIP_CODE, NULL);
      buffer[1] = ((tmp  = xmlNodeGetContent(nodo)) ?  tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_CITY, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_PROVINCE, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ?  tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_COUNTRY, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_WEB, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");

      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_EMAIL, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] =  gconf_client_get_string(client, RUBRICA_KEY_DICT_OPERATOR, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
//      buffer[0] =  gconf_client_get_string(client, RUBRICA_KEY_DICT_FAX, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_GREEN, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_CUSTOMER_CARE, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_NOTES, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
    }

  figlio = figlio->next;
  if (xmlIsBlankNode(figlio))
    figlio = figlio->next;
  if (figlio && figlio->name &&
      g_strcasecmp(figlio->name, "Work") == 0)  
    {
      xmlNodePtr nodo;
      gchar *buffer[2], *tmp;

      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_WORK, NULL);
      buffer[1] = "";
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 10, 
					 NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = figlio->children;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_ASSIGMENT, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : ""); 
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
      
      nodo   = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_ORGANIZATION, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
      
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_DEPARTMENT, NULL);
      buffer[1] = ((tmp  = xmlNodeGetContent(nodo)) ?  tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
      
      nodo = nodo->next;      
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_SUB_DEPARTMENT, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
      
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_SECRETARY, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ?  tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
      
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_SECRETARY_PHONE, 
					  NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
    }

  figlio = figlio->next;
  if (xmlIsBlankNode(figlio))
    figlio = figlio->next;
  if (figlio && figlio->name &&
      g_strcasecmp(figlio->name, "Notes") == 0)  
    {
      xmlNodePtr nodo;
      gchar *buffer[2], *buffer2[2], *tmp;
      
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_NOTES, NULL);
      buffer[1] = "";
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 10, 
					 NULL, NULL, NULL, NULL, FALSE, TRUE);
      
      tmp = xmlGetProp(figlio, "married");
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_MARRIED, NULL);
      buffer[1] = rubrica_convert_boolean(tmp);
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
					 
      tmp = xmlGetProp(figlio, "child");
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_CHILDREN, NULL);;
      buffer[1] = rubrica_convert_boolean(tmp);
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
					  
      nodo = figlio->children;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_SPOUSE_NAME, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);

      tmp = xmlGetProp(nodo, "birthday");
      buffer2[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_BIRTHDAY, NULL);
//      buffer2[1] = rubrica_convert_time(atoi(tmp), FALSE);
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer2, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);

      tmp = xmlGetProp(nodo, "anniversary");
      buffer2[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_ANNIVERSARY, NULL);
//      buffer2[1] = rubrica_convert_time(atoi(tmp), FALSE);
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer2, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
       
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_CHILDREN_NOTES, 
					  NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_HOBBY, NULL);
      buffer[1] = ((tmp  = xmlNodeGetContent(nodo)) ?  tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
          
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_OTHER_NOTES, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
      
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_PUBLIC_KEY,  NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ?  tmp : "");      
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
			    NULL, NULL, NULL, NULL, FALSE, TRUE);
    }  
}

void rubrica_preview_parse_old_node(xmlNodePtr xmlnode, GtkWidget *ctree, 
				    GtkCTreeNode *radice)
{
  GConfClient *client;
  xmlNodePtr figlio;  
  GtkCTreeNode *genitore = NULL;
  GtkCTreeNode *treefiglio = NULL;

  client = gconf_client_get_default(); // rubrica_get_client();
  
  if (xmlnode && xmlnode->name &&                      /* se il nodo ha nome e */
      (g_strcasecmp(xmlnode->name, "Address") == 0 ||  /* il nome  Indirizzo  */
       g_strcasecmp(xmlnode->name, "Indirizzo") == 0))
    {
      gchar *buffer[2];
      
      buffer[0] = g_strdup(gconf_client_get_string(client, RUBRICA_KEY_DICT_ADDRESS, 
						   NULL));
      buffer[1] = ""; 

      genitore = gtk_ctree_insert_node(GTK_CTREE(ctree), radice, NULL, buffer, 
				       10, NULL, NULL, NULL, NULL, FALSE, FALSE);   
    }

  figlio = xmlnode->children;
  if (xmlIsBlankNode(figlio))
    figlio = figlio->next;
  if (figlio && figlio->name &&
      (g_strcasecmp(figlio->name, "Card") == 0 ||
       g_strcasecmp(figlio->name, "Scheda") == 0 ))  
    {
      xmlNodePtr nodo;
      gchar *buffer[2], *tmp;

      nodo = figlio->children;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_CARD, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : ""); 
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 
					 10, NULL, NULL, NULL, NULL, FALSE, TRUE);
    }
  
  
  figlio = figlio->next;
  if (xmlIsBlankNode(figlio))
    figlio = figlio->next;
  if (figlio && figlio->name &&
      (g_strcasecmp(figlio->name, "Data") == 0 ||
       g_strcasecmp(figlio->name, "Dati") == 0))  
    {      
      xmlNodePtr nodo;
      gchar *buffer[2], *tmp;
      
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_DATA, NULL);
      buffer[1] = "";
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 
					 10, NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = figlio->children;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_FIRST_NAME, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : ""); 
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, FALSE);
          
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_LAST_NAME, NULL);
      buffer[1] = ((tmp  = xmlNodeGetContent(nodo)) ?  tmp : "");  
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, FALSE);
      
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_PROFESSION, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, FALSE);
      
      nodo = nodo->next;    
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_STREET, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : ""); 
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, TRUE);    
  
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_STREET_NUMBER, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, TRUE);
      
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_ZIP_CODE, NULL);
      buffer[1] = ((tmp  = xmlNodeGetContent(nodo)) ?  tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_CITY, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_PROVINCE, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ?  tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, TRUE);
      
      nodo = nodo->next;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_STATE, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : "");
      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 
			    10, NULL, NULL, NULL, NULL, FALSE, TRUE);
    }

  figlio = figlio->next;
  if (xmlIsBlankNode(figlio))
    figlio = figlio->next;
  if (figlio && figlio->name &&
      (g_strcasecmp(figlio->name, "WebAddresses") == 0 ||
       g_strcasecmp(figlio->name, "IndirizziWeb") == 0 ))  
    {
      xmlNodePtr nodo;
      gchar *buffer[2];

      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_WEB_ADDRESS, NULL);
      buffer[1] = "";
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 
					 10, NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = figlio->children;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      while (nodo)
	{
	  gchar *tmp;

	  tmp = xmlNodeGetContent(nodo);
	  if (tmp)
	    {
	      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_WEB, NULL);
	      buffer[1] = tmp;
	      
	      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
				    NULL, NULL, NULL, NULL, FALSE, TRUE);

	      nodo = nodo->next;
	      if (nodo && xmlIsBlankNode(nodo))
		nodo = nodo->next;
	    }
	}    
    }      

  figlio = figlio->next;
  if (xmlIsBlankNode(figlio))
    figlio = figlio->next;
  if (figlio && figlio->name &&
      (g_strcasecmp(figlio->name, "EmailAddresses") == 0 ||
       g_strcasecmp(figlio->name, "IndirizziEmail") == 0))  
    {
      xmlNodePtr nodo;
      gchar *buffer[2];

      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_EMAIL_ADDRESS, NULL);
      buffer[1] = "";
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 
					 10, NULL, NULL, NULL, NULL, FALSE, TRUE);

      nodo = figlio->children;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      while (nodo)
	{
	  gchar *tmp;

	  tmp = xmlNodeGetContent(nodo);
	  if (tmp)
	    {
	      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_EMAIL, NULL);
	      buffer[1] = tmp;
      
	      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10,
				    NULL, NULL, NULL, NULL, FALSE, TRUE);	      
	      
	      nodo = nodo->next;
	      if (nodo && xmlIsBlankNode(nodo))
		nodo = nodo->next;
	    }
	}    
    }

  figlio = figlio->next;
  if (xmlIsBlankNode(figlio))
    figlio = figlio->next;
  if (figlio && figlio->name &&
      (g_strcasecmp(figlio->name, "TelephoneNumbers") == 0 ||
       g_strcasecmp(figlio->name, "NumeriTelefonici") == 0))  
    {
      xmlNodePtr nodo;
      gchar *buffer[2];

      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_TELEPHONE_LIST, 
					  NULL);
      buffer[1] = "";
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 
					 10, NULL, NULL, NULL, NULL, FALSE, TRUE);      
      nodo = figlio->children;
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      while (nodo)
	{
	  gchar *tmp1 = NULL, *tmp2 = NULL;

	  tmp1 = xmlNodeGetContent(nodo);
	  if ((strcmp(nodo->properties->name, "type") == 0))
	    tmp2 = xmlGetProp(nodo, "type");
	  if((strcmp(nodo->properties->name, "Tipo") == 0))
	    tmp2 = xmlGetProp(nodo, "Tipo");

	  if (tmp1)
	    {
	      buffer[0] = gconf_client_get_string(client, 
						  RUBRICA_KEY_DICT_TELEPHONE_NUMBER, 
						  NULL);
	      buffer[1] = tmp1;
	      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
				    NULL, NULL, NULL, NULL, FALSE, TRUE);

	      buffer[0] =  gconf_client_get_string(client, 
						   RUBRICA_KEY_DICT_TELEPHONE_TYPE, 
						   NULL);
	      buffer[1] = tmp2;
	      gtk_ctree_insert_node(GTK_CTREE(ctree), treefiglio, NULL, buffer, 10, 
				    NULL, NULL, NULL, NULL, FALSE, TRUE);	      
	      
	      nodo = nodo->next;
	      if (nodo && xmlIsBlankNode(nodo))
		nodo = nodo->next;
	    }
	}    
    }

  figlio = figlio->next;
  if (xmlIsBlankNode(figlio))
    figlio = figlio->next;
  if (figlio && figlio->name &&
      (g_strcasecmp(figlio->name, "Notes") == 0 ||
       g_strcasecmp(figlio->name, "Note") == 0))  
    {
      xmlNodePtr nodo = figlio->children;
      gchar *buffer[2], *tmp;
      
      if (xmlIsBlankNode(nodo))
	nodo = nodo->next;
      buffer[0] = gconf_client_get_string(client, RUBRICA_KEY_DICT_NOTES, NULL);
      buffer[1] = ((tmp = xmlNodeGetContent(nodo)) ? tmp : ""); 
      treefiglio = gtk_ctree_insert_node(GTK_CTREE(ctree), genitore, NULL, buffer, 10, 
					 NULL, NULL, NULL, NULL, FALSE, TRUE);    
    }  
}


gchar *rubrica_convert_boolean(gchar *str)
{
  if(!str)
    return "???";
  
  if (strcasecmp(str, "true") == 0)
    return _("yes");

  return _("no");
}
